/**
 * Copyright 2010 Xeus Technologies 
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 */
package org.xeustechnologies.esl4j.impl;

import java.util.Map;

import org.xeustechnologies.esl4j.LogFactory;
import org.xeustechnologies.esl4j.Logger;

import android.util.Log;

/**
 * A LogFactory for logging messages to Android console
 * 
 * @author Kamran
 * 
 */
public class AndroidLogFactory implements LogFactory {

    public Logger getLogger(Class clazz) {
        return new AndroidLogger( clazz.getName() );
    }

    public void setProperties(Map<String, String> props) {
    }

    public static final class AndroidLogger implements Logger {
        private final String tag;

        public AndroidLogger(String tag) {
            this.tag = tag;
        }

        public void debug(String message) {
            if( isDebugEnabled() )
                Log.d( tag, message );
        }

        public void debug(Throwable error) {
            if( isDebugEnabled() )
                Log.d( tag, "", error );
        }

        public void debug(String message, Throwable error) {
            if( isDebugEnabled() )
                Log.d( tag, message, error );
        }

        public void error(String message) {
            if( isErrorEnabled() )
                Log.e( tag, message );
        }

        public void error(Throwable error) {
            if( isErrorEnabled() )
                Log.e( tag, "", error );
        }

        public void error(String message, Throwable error) {
            if( isErrorEnabled() )
                Log.e( tag, message, error );
        }

        public void info(String message) {
            if( isInfoEnabled() )
                Log.i( tag, message );
        }

        public void info(Throwable error) {
            if( isInfoEnabled() )
                Log.i( tag, "", error );
        }

        public void info(String message, Throwable error) {
            if( isInfoEnabled() )
                Log.i( tag, message, error );
        }

        public boolean isDebugEnabled() {
            return Log.isLoggable( tag, Log.DEBUG );
        }

        public boolean isErrorEnabled() {
            return Log.isLoggable( tag, Log.ERROR );
        }

        public boolean isInfoEnabled() {
            return Log.isLoggable( tag, Log.INFO );
        }

        public boolean isTraceEnabled() {
            return Log.isLoggable( tag, Log.DEBUG );
        }

        public boolean isVerboseEnabled() {
            return Log.isLoggable( tag, Log.VERBOSE );
        }

        public boolean isWarnEnabled() {
            return Log.isLoggable( tag, Log.WARN );
        }

        public void trace(String message) {
            if( isDebugEnabled() )
                Log.d( tag, message );
        }

        public void trace(Throwable error) {
            if( isDebugEnabled() )
                Log.d( tag, "", error );
        }

        public void trace(String message, Throwable error) {
            if( isDebugEnabled() )
                Log.d( tag, message, error );
        }

        public void verbose(String message) {
            if( isVerboseEnabled() )
                Log.v( tag, message );
        }

        public void verbose(Throwable error) {
            if( isVerboseEnabled() )
                Log.v( tag, "", error );
        }

        public void verbose(String message, Throwable error) {
            if( isVerboseEnabled() )
                Log.v( tag, message, error );
        }

        public void warn(String message) {
            if( isWarnEnabled() )
                Log.w( tag, message );
        }

        public void warn(Throwable error) {
            if( isWarnEnabled() )
                Log.w( tag, "", error );
        }

        public void warn(String message, Throwable error) {
            if( isWarnEnabled() )
                Log.w( tag, message, error );
        }
    }
}
